@@ -1,14 +1,14 @@
 package cgrouputil
 
 import (
+	"errors"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
 
 	"github.com/moby/sys/mountinfo"
-	"github.com/pkg/errors"
+
 	"github.com/sirupsen/logrus"
 )
 
@@ -25,7 +25,7 @@ func EvacuateCgroup2(evac string) error {
 		return errors.New("got empty evacuation group name")
 	}
 	if strings.Contains(evac, "/") {
-		return errors.Errorf("unexpected evacuation group name %q: must not contain \"/\"", evac)
+		return fmt.Errorf("unexpected evacuation group name %q: must not contain \"/\"", evac)
 	}
 
 	mountpoint := findCgroup2Mountpoint()
@@ -50,7 +50,7 @@ func EvacuateCgroup2(evac string) error {
 	}
 
 	// evacuate existing procs from oldGroup to newGroup, so that we can enable all controllers including threaded ones
-	cgroupProcsBytes, err := ioutil.ReadFile(filepath.Join(oldPath, "cgroup.procs"))
+	cgroupProcsBytes, err := os.ReadFile(filepath.Join(oldPath, "cgroup.procs"))
 	if err != nil {
 		return err
 	}
@@ -58,19 +58,19 @@ func EvacuateCgroup2(evac string) error {
 		if pidStr == "" || pidStr == "0" {
 			continue
 		}
-		if err := ioutil.WriteFile(filepath.Join(newPath, "cgroup.procs"), []byte(pidStr), 0644); err != nil {
+		if err := os.WriteFile(filepath.Join(newPath, "cgroup.procs"), []byte(pidStr), 0644); err != nil {
 			logrus.WithError(err).Warnf("failed to move process %s to cgroup %q", pidStr, newGroup)
 		}
 	}
 
 	// enable controllers for all subgroups under the oldGroup
-	controllerBytes, err := ioutil.ReadFile(filepath.Join(oldPath, "cgroup.controllers"))
+	controllerBytes, err := os.ReadFile(filepath.Join(oldPath, "cgroup.controllers"))
 	if err != nil {
 		return err
 	}
 	for _, controller := range strings.Fields(string(controllerBytes)) {
 		logrus.Debugf("enabling controller %q", controller)
-		if err := ioutil.WriteFile(filepath.Join(oldPath, "cgroup.subtree_control"), []byte("+"+controller), 0644); err != nil {
+		if err := os.WriteFile(filepath.Join(oldPath, "cgroup.subtree_control"), []byte("+"+controller), 0644); err != nil {
 			logrus.WithError(err).Warnf("failed to enable controller %q", controller)
 		}
 	}
@@ -96,7 +96,7 @@ func findCgroup2Mountpoint() string {
 
 func getCgroup2(pid int) string {
 	p := fmt.Sprintf("/proc/%d/cgroup", pid)
-	b, err := ioutil.ReadFile(p)
+	b, err := os.ReadFile(p)
 	if err != nil {
 		logrus.WithError(err).Warnf("failed to read %q", p)
 		return ""
